@@ -265,7 +265,10 @@ class StringLiteral(BaseType):
         if options.get(self.TypeStyle.use_literals):
             limit = options.get(self.TypeStyle.max_literals)
             if limit is None or len(self.literals) < limit:
-                parts = ', '.join(f'"{s}"' for s in sorted(self.literals))
+                parts = ', '.join(
+                    '"{}"'.format(s.replace('\\', '\\\\').replace('"', '\\"'))
+                    for s in sorted(self.literals)
+                )
                 return [(Literal.__module__, 'Literal')], f"Literal[{parts}]"
 
         return [], 'str'
